@@ -77,7 +77,8 @@ def model_metrics(model, x_train, y_train, x_test, y_test, show_graphs='Y', f_sc
     
     # Determine log-loss cutpoint
     multi=10000
-    class_ratio = [np.round(score_test['actual'].mean(),3), 1-np.round(score_test['actual'].mean(),3)]
+    class_ratio = [actual, 1-actual]
+    class_ratio = [round(i, 3) for i in class_ratio]
     
     actuals=[]
     for i,val in enumerate(class_ratio):
